/* 
 * This file is part of the Echo Point Project.  This project is a collection
 * of Components that have extended the Echo Web Application Framework.
 *
 * EchoPoint is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * EchoPoint is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Echo Point; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

//========================================================================================================
// Globals
//========================================================================================================
var g_epbePopUpMap = new Array();
var g_popupCurrentW = null;

//- - - - - - - - - - - - - - - - - - - - 
// Document On Click Handler for Popups
//- - - - - - - - - - - - - - - - - - - - 
function epPopupDocumentOnClickHandler(event) {
	var targetHtmlE = null;
	if (browser.isIE)
		targetHtmlE = window.event.srcElement;
	else
		targetHtmlE = event.target;
	//
	// check that the click wasnt on the current popup
	// otherwise default behaviour wont happen
	//
	if (popupClickIsOnCurrentW(targetHtmlE))
		return;
	
	popupHideAll(true);
}

//- - - - - - - - - - - - - - - - - - - - 
// Returns true if the click target was
// within the current popup htmlE
//- - - - - - - - - - - - - - - - - - - - 
function popupClickIsOnCurrentW(targetHtmlE) {
	if (g_popupCurrentW == null || targetHtmlE == null)
		return false;

	if (g_popupCurrentW.E.htmlE == targetHtmlE)
		return true;

	if (browser.isDOM) {
		while (targetHtmlE.parentNode) {
			targetHtmlE = targetHtmlE.parentNode;
			if (g_popupCurrentW.E.htmlE == targetHtmlE)
				return true;
		}
	}
	return false;
}

//- - - - - - - - - - - - - - - - - - - - 
// Does nothing
//- - - - - - - - - - - - - - - - - - - - 
function popupNoop() {;}

//- - - - - - - - - - - - - - - - - - - - 
// Hides all popups
//- - - - - - - - - - - - - - - - - - - - 
function popupHideAll(doSaveState) {
	for (popupW in g_epbePopUpMap) {
		g_epbePopUpMap[popupW].hide(doSaveState);
	}        
	g_popupCurrentW = null;
}

//- - - - - - - - - - - - - - - - - - - - 
// Hides an individual popup by Id
//- - - - - - - - - - - - - - - - - - - - 
function popupHideById(htmlId) {
 	var popupE = getElementById(htmlId);
 	var popupW = g_epbePopUpMap[htmlId];
	if (popupE == null || popupW == null)
		return;
	popupW.E = popupE;
	popupW.hide();
}

//- - - - - - - - - - - - - - - - - - - - 
// Swap Shows an individual popup by Id
//
// If the current Popup is the new popup
// then the Popup is hidden
//- - - - - - - - - - - - - - - - - - - - 
function popupSwapById(event,htmlId) {

	var popupE = getElementById(htmlId);
	var popupW = g_epbePopUpMap[htmlId];
	if (popupE == null || popupW == null)
		return;
	popupW.E = popupE;
	popupW.registerEventHandler();
	
	popupW.swap();
	epbe_CancelEvent(event);
}

//- - - - - - - - - - - - - - - - - - - - 
// Shows an individual popup by Id, with an 
// OPTIONAL nextToHtmlId that puts the 
// popup just above the other element
//- - - - - - - - - - - - - - - - - - - - 
function popupShowById(htmlId) {

 	var popupE = getElementById(htmlId);
 	var popupW = g_epbePopUpMap[htmlId];
	if (popupE == null || popupW == null)
		return;
		
	popupW.E = popupE;
	popupW.registerEventHandler();
	
	popupHideAll(true);
	popupW.show();
}

//- - - - - - - - - - - - - - - - - - - - 
// PopupWindow Class.
//- - - - - - - - - - - - - - - - - - - - 
function EPPopupWindow(htmlId, autoCollapse, nextToHtmlId) {
	this.htmlId = htmlId;
	this.autoCollapse = autoCollapse; 
	this.nextToHtmlId = nextToHtmlId;
	
	this.expanded = false;
	this.E = null;
	this.nextToE = null;
	this.registered = false;

	g_epbePopUpMap[htmlId] = this;
}

//- - - - - - - - - - - - - - - - - - - - 
// Shows a popup Window
//- - - - - - - - - - - - - - - - - - - - 
EPPopupWindow.prototype.show = function() {
	g_popupCurrentW = this;
	if (this.nextToE == null && this.nextToHtmlId != null)
		this.nextToE = getElementById(this.nextToHtmlId);
		
	this.E.setStyle('display','');
	if (this.nextToE != null) {
		var ph = this.E.getHeight();
		var x = this.nextToE.getPageX();
		var y = this.nextToE.getPageY();
		var scrollX = this.nextToE.calcScrollX();
		var scrollY = this.nextToE.calcScrollY();
		y = y-ph-scrollY;
		x = x-scrollX;
		if (x < 0)
			x = 0;
		if (y < 0)
			y = 0;
		this.E.setX(x);
		this.E.setY(y);
	}
	if (browser.isIE)
		epbe_hideSelectFieldsUnder(this.htmlId);
	this.E.setStyle('visibility','visible');

	this.expanded = true;
	this.saveState();
}

//- - - - - - - - - - - - - - - - - - - - 
// Hides an individual popup Window
//- - - - - - - - - - - - - - - - - - - - 
EPPopupWindow.prototype.hide = function(doSaveState) {
	if (this.E) {
		if (browser.isIE)
			epbe_showSelectFieldsUnder(this.htmlId);
		this.E.setStyle('display','none');
		this.E.setStyle('visibility','hidden');
	}
		
	if (doSaveState) {
		this.expanded = false;
		this.saveState();
	}
}


//- - - - - - - - - - - - - - - - - - - - 
// Swaps the current popup window.  That is
// it hides the current one and shows a new 
// one if necessary.
//- - - - - - - - - - - - - - - - - - - - 
EPPopupWindow.prototype.swap = function() {
	//
	// if the previous popup window was the current one
	// then hide it, otherwise normal window showing 
	//
	if (g_popupCurrentW == this) {
		popupHideAll(true);
	} else {
		popupHideAll(true);
		this.show();
	}
}

//- - - - - - - - - - - - - - - - - - - - 
// Save the component state
//- - - - - - - - - - - - - - - - - - - - 
EPPopupWindow.prototype.saveState = function() {
	if (E_setParameter)
		E_setParameter(this.htmlId, "" + this.expanded);
}

//- - - - - - - - - - - - - - - - - - - - 
// Event handler registratin
//- - - - - - - - - - - - - - - - - - - - 
EPPopupWindow.prototype.registerEventHandler = function() {
	if (this.registered == false) {
		this.E = getElementById(this.htmlId);
		this.nextToE = getElementById(this.nextToHtmlId);
		
		//epbe_AddEventHandler(this, this.E.htmlE, 	   window, "click");
		//epbe_AddEventHandler(this, this.nextToE.htmlE, window, "click");
		this.registered = true;
	}
}

//- - - - - - - - - - - - - - - - - - - - 
// Event handler
//- - - - - - - - - - - - - - - - - - - - 
EPPopupWindow.prototype.eventHandler = function(event) {
	var targetHtmlE = null;
	if (browser.isIE)
		targetHtmlE = window.event.srcElement;
	else
		targetHtmlE = event.target;
	if (targetHtmlE = this.nextToE.htmlE) {
		this.swap();
	} else {
		// dont do anything if we have clicked on our content
	}
	epbe_CancelEvent(event);
}


epbe_registerDocumentEventHandler("click",epPopupDocumentOnClickHandler,"epbe_popup");
