/*
 * This file is part of the SOAFaces Project (hereinafter "SOAFaces").
 * Copyright (C) 2006 Grand Logic, Inc.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.soafaces.bundle.client.rpc;

/**
 * Simple class used to relay success or failure of a asynchronous call.
 * 
 * @author Sam Taha
 */
public abstract class SuccessFailCallback {

  public SuccessFailCallback() {
  }

  /**
   * Invoke this method if action was successful.
   */
  final public void returnSuccess() {
    onSuccess();
  }

  /**
   * Invoke this method if action had errors.
   * @param errorMsg
   */
  final public void returnFailure(String errorMsg) {
    onFailure(errorMsg);
  }

  /**
   * Invoke this method if action had errors.
   */
  final public void returnFailure() {
    onFailure();
  }

  protected abstract void onSuccess();

  protected abstract void onFailure();
  
  protected abstract void onFailure(String errorMsg);
}
